@@ -1,20 +1,24 @@
 #' Parse and resolve a scientific name string
 #'
+#' This function is depreciated. Please use \link{check_scientific}
+#'
 #' Parse the names using GBIF parse API to make sure the name passed
 #' is an scientific name
 #'
 #' @param name scientific name string to be checked
 #' @return Resolved Canonical name and NULL is not matched
 #'
-#' @family Name functions
+#' @family Discontinued functions
 #' @importFrom taxize gbif_parse gnr_resolve
 #' @examples
+#' \dontrun{
 #' CheckScientificName("Akodon longipilis (Waterhouse, 1837)")
 #' CheckScientificName("Mus longipilis Waterhouse, 1837")
 #' CheckScientificName("Akodon hershkovitzi Patterson, Gallardo, and Freas, 1984")
-#'
+#' }
 #' @export
 CheckScientificName <- function(name){
+  .Deprecated("check_scientific")
   res <- gnr_resolve(name)
   if(dim(res)[1]>0){
     res1 <- tryCatch({gbif_parse(res$matched_name[1])},
