@@ -1,9 +1,11 @@
 #' Get Wikipedia Synonyms for list of names
 #'
+#' This function is depreciated. Please use \link{list_wiki_syn}
+#'
 #' Fetch Synonyms from Wikipedia and clean them for use
 #'
 #' @param namelist list of scientific names
-#' @family Wiki functions
+#' @family Discontinued functions
 #' @return a data frame containing names, synonyms and Canonical synonyms matched
 #'    with GBIF backbone taxonomy  \itemize{ \item{Name}  {: Scientific name}
 #'    \item{OrigSyn}  {: Original synonym returned by Wikipedia}
@@ -11,11 +13,12 @@
 #' @importFrom wikitaxa wt_wikipedia
 #' @importFrom taxize gbif_parse
 #' @examples
-#' GetWikiSyn("Abrothrix illutea")
+#' #GetWikiSyn("Abrothrix illutea")
 #' #GetWikiSyn(c("Abditomys latidens", "Abeomelomys sevia", "Abrocoma schistacea"))
 #'
 #' @export
 GetWikiSyn <- function(namelist){
+  .Deprecated("ist_wiki_syn")
   res <- NULL
   for(i in 1:length(namelist)){
     accname <- namelist[i]
@@ -28,11 +31,11 @@ GetWikiSyn <- function(namelist){
       }
     }
     if(length(wikisyn)>0){
-      wikisyn <- ExpandSyn(accname,wikisyn)
+      wikisyn <- expand_name(accname,wikisyn)
       synlst <- NULL
       for(j in 1:length(wikisyn)){
         rec <- taxize::gbif_parse(wikisyn[j])
-        syn <- CheckScientificName(rec$canonicalname)
+        syn <- check_scientific(rec$canonicalname)
         if(is.null(syn)){
           syn <- ''
         }
